@@ -2,7 +2,7 @@
 
 Usage:
   cloudmesh-installer git key [LOCATION] [--benchmark]
-  cloudmesh-installer git [clone|pull|status] [BUNDLES...] [--benchmark]
+  cloudmesh-installer git [clone|pull|status|authors] [BUNDLES...] [--benchmark]
   cloudmesh-installer get [BUNDLES...] [--benchmark]
   cloudmesh-installer update [BUNDLELES...] [--benchmark]
   cloudmesh-installer install [BUNDLES...] [--venv=ENV | -e] [--benchmark]
@@ -11,7 +11,7 @@ Usage:
   cloudmesh-installer info [BUNDLE] [--verbose]
   cloudmesh-installer clean --dir=DIR [--force]
   cloudmesh-installer clean --venv=ENV [--force]
-  cloudmesh-installer new VENV
+  cloudmesh-installer new VENV [BUNDLES...]
   cloudmesh-installer release [REPOS...] [--benchmark]
 
 
@@ -290,11 +290,13 @@ repos = dict({
     ],
 
     'analytics': cms + [
+        'cloudmesh-cloud',
         'cloudmesh-analytics',
         'cloudmesh-openapi',
     ],
 
     'openapi': cms + [
+        'cloudmesh-cloud',
         'cloudmesh-openapi',
     ],
 
@@ -381,8 +383,18 @@ repos = dict({
             'sp19-616-112'
         ] \
         + hostlist.expand_hostlist("sp19-516-[22,26,29,121-125,127-139]") \
-        + hostlist.expand_hostlist("sp19-222-[89-94,96-102]")
+        + hostlist.expand_hostlist("sp19-222-[89-94,96-102]"),
 
+    'bookmanager':
+        [
+            'bookmanager'
+            'bookmanager-service'
+        ],
+
+    'book':
+        [
+            'book'
+        ]
 })
 
 
@@ -425,6 +437,10 @@ class Git(object):
             'sp20' in repo  or \
             'fa20' in repo:
             return f"https://github.com/cloudmesh-community/{repo}"
+        elif 'bookmanager' in repo:
+            return f"https://github.com/cyberaide/{repo}"
+        elif 'book' == repo:
+            return f"https://github.com/cloudmesh-community/{repo}"
         else:
             return f"https://github.com/cloudmesh/{repo}"
 
@@ -455,7 +471,15 @@ class Git(object):
                                  "already exists.")
 
     @staticmethod
-    def command(repos, name, ok_msg="nothing to commit, working tree clean"):
+    def version(repos):
+        for repo in repos:
+            with open(f"{repo}/VERSION") as f:
+                v = f.read().strip()
+            print(f"version {repo:30}:", v)
+
+
+    @staticmethod
+    def command(repos, name, ok_msg="nothing to commit, working tree clean", r=False):
         repos = OrderedSet(repos)
 
         for repo in repos:
@@ -475,7 +499,7 @@ class Git(object):
             os.chdir("../")
 
     @staticmethod
-    def _command(repos, command, ok_msg="nothing", verbose=False):
+    def _command(repos, command, ok_msg="Uploading", verbose=False, r=False):
         repos = OrderedSet(repos)
 
         for repo in repos:
@@ -487,6 +511,7 @@ class Git(object):
                 print(Fore.RED + "ERROR:", repo, "not found")
 
             result = run(f"{command}", verbose=False)
+
             if ok_msg in result:
                 print(Fore.GREEN + f"... ok")
             else:
@@ -505,6 +530,15 @@ class Git(object):
         Git.command(repos, "status",
                     ok_msg="nothing to commit, working tree clean")
 
+
+
+    @staticmethod
+    def authors(repos, error="ERROR"):
+
+        command = "shortlog -e -s -n"
+        Git.command(repos, command)
+
+
     @staticmethod
     def pull(repos):
         Git.command(repos, "pull", ok_msg="Already up to date.")
@@ -815,6 +849,10 @@ def main():
         repositories = _get_bundles()
         Git.pull(repositories)
 
+    elif arguments["authors"] and arguments["git"]:
+        repositories = _get_bundles()
+        Git.authors(repositories)
+
     elif arguments["key"] and arguments["git"]:
 
         try:
@@ -887,10 +925,15 @@ def main():
         result = Git._command(repositories, "make patch")
         result = Git._command(repositories, "make release")
 
+        StopWatch.status("make patch", "released")
+        StopWatch.status("make release", "released")
+
         StopWatch.benchmark(sysinfo=True)
 
+        Git.version(repositories)
+
         if testing:
-            os.environ["TESTING"] = 1
+            os.environ["TESTING"] = "1"
 
     elif arguments["--venv"] and arguments["clean"]:
         environment = arguments["--venv"]
@@ -988,6 +1031,15 @@ def main():
 
             os.system(script)
 
+
+            if bundles:
+
+                print()
+                print("Installing Bundles")
+                print()
+                repositories = _get_bundles()
+                Git.get(repositories)
+
             print()
             print(
                 "You can add the following to your .bashrc or .bash_profile" or ".zprofile")
